function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { createElement } from 'rax';

function Root(props, context) {
  var __initialHtml = context.__initialHtml; // comment node for ssr parse root node position

  if (process.env.__IS_SERVER__) {
    return [{
      __html: '<!--__BEFORE_ROOT__-->'
    }, createElement("div", {
      id: "root",
      key: "root",
      dangerouslySetInnerHTML: {
        __html: __initialHtml || ''
      }
    }), {
      __html: '<!--__AFTER_ROOT__-->'
    }];
  }

  return createElement("div", {
    id: "root",
    key: "root",
    dangerouslySetInnerHTML: {
      __html: __initialHtml || ''
    }
  });
}

function Manifest(props, context) {
  var __manifests = context.__manifests,
      __pagePath = context.__pagePath;

  if (Array.isArray(__manifests)) {
    var manifest = __manifests.find(function (item) {
      return item.path === __pagePath;
    }); // manifest json type: https://developer.mozilla.org/en-US/docs/Web/Manifest#Deploying_a_manifest_with_the_link_tag


    if (manifest && manifest.data) {
      return createElement("script", {
        type: "application/manifest+json",
        dangerouslySetInnerHTML: {
          __html: JSON.stringify(manifest.data)
        }
      });
    }
  }

  return null;
}

function Data(props, context) {
  var __initialData = context.__initialData;

  if (__initialData) {
    return createElement("script", {
      "data-from": "server",
      dangerouslySetInnerHTML: {
        __html: 'window.__INITIAL_DATA__=' + __initialData
      }
    });
  }

  return null;
} // Named by role rather than implementationm, so component name are `Style` rather than `Styles`.


function Style(props, context) {
  var _context$__styles = context.__styles,
      __styles = _context$__styles === void 0 ? [] : _context$__styles;

  return __styles.map(function (src, index) {
    return createElement("link", _extends({}, props, {
      rel: "stylesheet",
      href: src,
      key: "style_" + index
    }));
  });
}

function Script(props, context) {
  var _context$__scripts = context.__scripts,
      __scripts = _context$__scripts === void 0 ? [] : _context$__scripts; // props such as type can be passed to script tag
  // script default crossorigin value is anonymous


  return __scripts.map(function (src, index) {
    return createElement("script", _extends({
      crossorigin: "anonymous"
    }, props, {
      src: src,
      key: "script_" + index
    }));
  });
}

function App(props, context) {
  var config = props.config || {};
  var routes = config.routes || [];
  var pagePath = context.__pagePath;
  var currentPageInfo = routes.find(function (route) {
    return route.path == pagePath;
  });
  var consumer = Array.isArray(props.children) ? props.children[0] : props.children;

  if (typeof consumer === 'function') {
    return consumer(currentPageInfo);
  }

  return props.children;
}

export { Root, Data, Style, Script, App, Manifest };